<?php

namespace App\Http\Controllers;

use App\Models\Estudiantes;
use App\Models\Tutores;
use Illuminate\Http\Request;

class GestionTutoresController extends Controller
{
    public function index()
{
    $tutores = Tutores::with('estudiantes')->paginate(5);  // Cargar estudiantes con el tutor
    return view('gestion_tutores.index', compact('tutores'));
}
    public function create()
    {
        // Obtener todos los estudiantes activos para poder asignarlos
        $estudiantes = Estudiantes::all();
        return view('gestion_tutores.crear', compact('estudiantes'));
    }
    
    public function store(Request $request)
    {
        $messages = [
            'required' => 'El campo :attribute es obligatorio.',
            'numeric' => 'El campo :attribute debe ser un número.',
            'date' => 'El campo :attribute debe ser una fecha válida.',
            'digits' => 'El campo :attribute debe tener :digits dígitos.',
            'regex' => 'El campo :attribute no cumple con el formato válido.',
            'email' => 'El campo :attribute debe ser una dirección de correo válida.',
            'unique' => 'El carnet ya está registrado.',
        ];
    
        $request->validate([
            'nombre' => 'required',
            'apellidos' => 'required',
            'CI' => 'required|numeric|unique:tutores,CI',
            'fecha' => ['required', 'date'],
            'tel' => 'required|numeric|digits:8',
            'direccion' => ['required', 'regex:/^[a-zA-Z0-9\s#]+$/'],
            'correo' => 'required|email',
            'estudiantes' => 'nullable|array', // Permitir estudiantes opcionales
            'estudiantes.*' => 'exists:estudiantes,id', // Asegurar que los estudiantes existan
        ], $messages);
    
        // Crear el tutor
        $tutor = Tutores::create($request->except('estudiantes'));
    
        // Asignar estudiantes al tutor
        if ($request->has('estudiantes')) {
            $tutor->estudiantes()->attach($request->estudiantes);
        }
    
        $notificacion = 'El tutor se agregó correctamente.';
        return redirect()->route('gestion_tutores.index')->with(compact('notificacion'));
    }
    
    public function edit(Tutores $gestion_tutore)
    {
        return view('gestion_tutores.editar', compact('gestion_tutore'));
    }
    
    public function buscar(Request $request)
    {
        $query = $request->input('query');

        // Realiza la búsqueda en la base de datos
        $tutores = Tutores::where('CI', 'LIKE', '%' . $query . '%')->paginate(10);
        return view('gestion_tutores.index', compact('tutores'));
    }
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Tutores $tutor)
    {
        $messages = [
            'required' => 'El campo :attribute es obligatorio.',
            'numeric' => 'El campo :attribute debe ser un número.',
            'date' => 'El campo :attribute debe ser una fecha válida.',
            'digits' => 'El campo :attribute debe tener :digits dígitos.',
            'regex' => 'El campo :attribute no cumple con el formato válido.',
            'email' => 'El campo :attribute debe ser una dirección de correo válida.',
        ];
    
        $request->validate([
            'nombre' => 'required',
            'apellidos' => 'required',
            'CI' => 'required|numeric',
            'fecha' => ['required', 'date'],
            'tel' => 'required|numeric|digits:8',
            'direccion' => ['required', 'regex:/^[a-zA-Z0-9\s#]+$/'],
            'correo' => 'required|email',
            'estudiantes' => 'nullable|array', // Permitir estudiantes opcionales
            'estudiantes.*' => 'exists:estudiantes,id', // Asegurar que los estudiantes existan
        ], $messages);
    
        // Actualizar el tutor
        $tutor->update($request->except('estudiantes'));
    
        // Asignar estudiantes al tutor
        if ($request->has('estudiantes')) {
            $tutor->estudiantes()->sync($request->estudiantes); // Sincronizar estudiantes
        }
    
        $notificacion = 'El tutor se actualizó correctamente';
        return redirect()->route('gestion_tutores.index')->with(compact('notificacion'));
    }
    
    public function destroy(Tutores $gestion_tutore)
    {
        // Cambiar el estado de 1 a 0 o viceversa
        $gestion_tutore->estado = $gestion_tutore->estado == 1 ? 0 : 1;
        $gestion_tutore->save();
    
        $notificacion = 'El estado del tutor ' . $gestion_tutore->nombre . ' se cambió correctamente';
        return redirect()->route('gestion_tutores.index')->with(compact('notificacion'));
    }
    
}
