<?php

namespace App\Http\Controllers;

use App\Models\Maestro;
use App\Models\Materia;
use Illuminate\Http\Request;

class MaestroMateriaController extends Controller
{
    // Mostrar todos los maestros y sus materias
    public function index()
    {
        $maestros = Maestro::with('materias')->get();
        return view('maestro_materia.index', compact('maestros'));
    }

    public function create(Maestro $maestro)
    {
        $materiasDisponibles = Materia::whereNotIn('id', $maestro->materias->pluck('id'))->get();
        return view('maestro_materia.create', compact('maestro', 'materiasDisponibles'));
    }
    
    public function store(Request $request)
    {
        $request->validate([
            'maestro_id' => 'required|exists:maestros,id',
            'materias' => 'required|array',
            'materias.*' => 'exists:materias,id',
        ]);
    
        $maestro = Maestro::findOrFail($request->maestro_id);
    
        // Validar que ninguna de las materias ya esté asignada a otro maestro
        $materiasYaAsignadas = Materia::whereIn('id', $request->materias)
            ->whereHas('maestros', function($query) use ($maestro) {
                $query->where('maestro_id', '!=', $maestro->id); // Aseguramos que la materia no esté asignada a otro maestro
            })
            ->pluck('nombre');
    
        if ($materiasYaAsignadas->isNotEmpty()) {
            return back()->withErrors([
                'materias' => 'Las siguientes materias ya están asignadas a otros maestros: ' . $materiasYaAsignadas->join(', ')
            ]);
        }
    
        // Asignar las materias al maestro
        $maestro->materias()->attach($request->materias);
    
        return redirect()->route('maestro_materia.index')->with('success', 'Materias asignadas correctamente.');
    }
    
    
    public function edit(Maestro $maestro)
{
    $materiasAsignadas = $maestro->materias; // Materias ya asignadas
    $materiasDisponibles = Materia::whereNotIn('id', $materiasAsignadas->pluck('id'))->get(); // Materias disponibles

    return view('maestro_materia.edit', compact('maestro', 'materiasAsignadas', 'materiasDisponibles'));
}

public function update(Request $request, Maestro $maestro)
{
    $request->validate([
        'materias' => 'required|array',
        'materias.*' => 'exists:materias,id',
    ]);

    // Validar que ninguna de las materias esté asignada a otro maestro
    $materiasYaAsignadas = Materia::whereIn('id', $request->materias)
        ->whereHas('maestros', function($query) use ($maestro) {
            $query->where('maestro_id', '!=', $maestro->id); // Verifica que la materia no esté asignada a otro maestro
        })
        ->pluck('nombre');

    if ($materiasYaAsignadas->isNotEmpty()) {
        return back()->withErrors([
            'materias' => 'Las siguientes materias ya están asignadas a otros maestros: ' . $materiasYaAsignadas->join(', ')
        ]);
    }

    // Actualizar las asignaciones
    $maestro->materias()->sync($request->materias);

    return redirect()->route('maestro_materia.index')->with('success', 'Materias actualizadas correctamente.');
}



public function destroy(Maestro $maestro, Materia $materia)
{
    // Desvincular la materia del maestro
    $maestro->materias()->detach($materia->id);

    return redirect()->route('maestro_materia.index')->with('success', 'Materia eliminada correctamente.');
}

    // Eliminar una materia asignada a un maestro
 
}
