<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class UsuarioController extends Controller
{
    function _construct(){
        

        $this->middleware('permission:ver-usuario|crear-usuario|editar-usuario|borrar-usuario',['only'=>['index']]);
        $this->middleware('permission:crear-usuario',['only'=>['create','store']]);
        $this->middleware('permission:editar-usuario',['only'=>['edit','update']]);
        $this->middleware('permission:borrar-usuario',['only'=>['destroy']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $searchQuery = $request->input('query');
    
        $usuarios = User::where('name', 'LIKE', "%$searchQuery%")
                        ->orWhere('email', 'LIKE', "%$searchQuery%")
                        ->orWhereHas('roles', function($roleQuery) use ($searchQuery) {
                            $roleQuery->where('name', 'LIKE', "%$searchQuery%");
                        })
                        ->paginate(5);
    
        return view('usuarios.index', compact('usuarios'));
    }
    

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $roles= Role::pluck('name','name')->all();
        return view('usuarios.crear',compact('roles'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    protected $firestoreUrl;
    protected $projectId;
    protected $privateKey;
    protected $clientEmail;
    
    public function __construct()
    {
        // Datos de configuración para Firebase
        $this->projectId = 'integrador-9f039';
        $this->firestoreUrl = 'https://firestore.googleapis.com/v1/projects/' . $this->projectId . '/databases/(default)/documents';
        $this->privateKey = "-----BEGIN PRIVATE KEY-----\nMIIEvQIBADANBgkqhkiG9w0BAQEFAASCBKcwggSjAgEAAoIBAQC2/JFdt39wDoZd\np2+K1grHTDn73il0LGzuiJ387/t/eGNKe2EMUKcFo9UKzg7c0DFn+ljjSIzMMbId\n3CuHdtO/PWJFyEQ2DmAdAs7JF9gsaWF7a+PuH+AwqFOwC+y63oEqVCD+ZVILSwvY\nerZynnf0+VOP/EyUW7lS+B3tJ/9yRgiQ5tVRYr6MgEJaBhr3c0f7LsNkJFC50x9G\nyyG5hSbsPf6TaJXTsM8EkNbPkLz2fITUykSbDzVjNfh0avhZohcNiThEGO31n9Hs\ngm33C4cExC/ke5l8OmK+2Hy2Qy2MgXE48/yUdf+QVsD96XWv9VPOfUClm0ei0oWA\nUwY4UY7TAgMBAAECggEAFVTsPVie6plG4LQcNLsvFny0ZcBIZNqo+EXE5S+0ye9m\n48/uSFk+n1GyDEhpQySiHdT5d8WFZGiGsyRvjqMznB+zzR7DlOmoGrmxEZBOCx9d\n1d2F/MSKhiGZX/SD7GTz+dNE5WM6ZUaiYuIrUsFWiqBmNWrcIo9u01VJZ9Q520BL\n89qhB+0HBNyzcy/q8bbQqMT/NPq+X+eCg7GA//qTLf3cYXtI6M8irlhFnWqmbKkn\n5S3SFJ7dfVgTmN30aZT2kqkp+lFsXXbYlW3yIrDjQaOuRavad9oeegvDjwLiJCP1\nEylWi3AQJPZFj+83m8eThfmwrmC/34AuYilcU+DoQQKBgQD1PXRNwwFSqwgzi641\nZUYAegZ8GzBasEZjn9I1vGMKb6v5x+fN4/d3wn3zV3u8kY8X02g+H1lpgX0gLxmg\nqj6pygs4qcGC83Y6gSJhyvoT3w4llX3NG/o+5orsGb/+caQJ6kJEAxa7uf1IUVkZ\nouD4mM7g4EFLo+q0V+b701SV5QKBgQC/A+FYBgBrA2NoEx9l6x1iUyEKovTrwx6/\nB5u/LDFI907sbFoZjvOpXqhVvcT9d/lWAf7d7IhsT3D48VyxO86lkcZ88IsywKXF\nHWsNfbncrewxIeK4Jai9ksy0+ZUbCG6nIsj8OkxhbISLf6MjqFCxm6NttThEXUMH\nfwPQld5GVwKBgF2j2YTXsOmf5MHJ0/sPcGs+LLu2pf/6zuW7YMij5i1V9pSpgBld\nsmBII0+HV/fonHq8flE6JyniB6UCVwbB+qtaOm6oYvtdewdbx4UPu+1afkxbiG2J\nAUSDQwhjzKubOMeQaz0M8OE9Yzj51suzJbPGpTe4aTY4oKW76ra9Os8BAoGAM3pa\nOpyzdCOfoKa2qYLpklwQ5YrxMrCNErJ8ONMyHRX5QSIaThUGebi26RSRiDXTDmjP\nRQO/6GCoc46oimMx19EnivhQq0bb5fl9pk8hzeVZaAxXy4TqqtxrKsKwem6VU5m+\nTKtxdjgGqImnb66mwJbPPnu+RD5WGCkU4BvjoVUCgYEAyaZZvfYdrY7RVwVBGfwf\nHQ/4qyEHslFcY2LbHMEwYT4cDEPBaBGxDbAAQ5udPBP+nvKHouVUwKGrul/OKd1c\nlU0cpZur8qdOU1rnqkPnO9H2wnsLaTdEXZt0k+/sK60Hg6o5ElXuubGP44EfdxQF\nD57oN0dNNfNcVZ0aAxbhOK8=\n-----END PRIVATE KEY-----\n";
        $this->clientEmail = 'firebase-adminsdk-oim2s@integrador-9f039.iam.gserviceaccount.com';
    }
    public function changeStatus(User $user)
    {
        try {
            // Actualizar el estado del usuario en la base de datos local
            $user->update(['estado' => !$user->estado]);
    
            // Verificar si el usuario tiene el rol "Estudiante"
            if ($user->hasRole('Estudiante')) {
                // Buscar el documento en Firestore por correo
                $response = Http::post($this->firestoreUrl . ':runQuery', [
                    'structuredQuery' => [
                        'from' => [['collectionId' => 'Users']],
                        'where' => [
                            'fieldFilter' => [
                                'field' => ['fieldPath' => 'correo'],
                                'op' => 'EQUAL',
                                'value' => ['stringValue' => $user->email],
                            ],
                        ],
                        'limit' => 1
                    ]
                ]);
    
                $existingEmail = $response->json();
    
                // Verificar si se encontró el documento
                if (isset($existingEmail[0]['document'])) {
                    // Extraer el ID relativo del documento
                    $documentName = $existingEmail[0]['document']['name'];
                    $relativePath = str_replace('projects/' . $this->projectId . '/databases/(default)/documents/', '', $documentName);
    
                    // Actualizar únicamente el campo estado en Firestore usando updateMask
                    $updateResponse = Http::patch($this->firestoreUrl . '/' . $relativePath . '?updateMask.fieldPaths=estado', [
                        'fields' => [
                            'estado' => ['integerValue' => (int) $user->estado],
                        ]
                    ]);
    
                    // Verificar si la actualización fue exitosa en Firestore
                    if (!$updateResponse->successful()) {
                        return back()->with('error', 'No se pudo actualizar el estado en Firestore.');
                    }
                } else {
                    return back()->with('error', 'No se encontró el usuario en Firestore.');
                }
            }
    
            // Mensaje de éxito si todo fue exitoso
            return back()->with('success', 'Estado del usuario actualizado exitosamente.');
        } catch (\Exception $e) {
            // Capturar cualquier excepción y retornar un error
            return back()->with('error', 'Error al actualizar el estado. Detalles: ' . $e->getMessage());
        }
    }
    
    
    public function store(Request $request)
    {
        $messages = [
            'name.required' => 'El nombre es obligatorio.',
            'email.required' => 'El correo electrónico es obligatorio.',
            'email.email' => 'El formato del correo electrónico no es válido.',
            'email.unique' => 'Este correo electrónico ya está registrado.',
            'password.required' => 'La contraseña es obligatoria.',
            'password.same' => 'Las contraseñas no coinciden.',
            'roles.nullable' => 'El campo de roles no puede ser nulo.',
        ];
    
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|same:confirm-password',
            'roles' => 'nullable',
        ], $messages);
    
        $input = $request->all();
        $input['password'] = Hash::make($input['password']);
        $user = User::create($input);
        $user->assignRole($request->input('roles'));
    
        return redirect()->route('usuarios.index');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user=User::find($id);
        $roles=Role::pluck('name','name')->all();
        $userRole=$user->roles->pluck('name','name')->all();
        return view('usuarios.editar',compact('user', 'roles', 'userRole'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request,[
            'name'=> 'required',
            'email'=>'required|email|unique:users,email,'.$id,
        'password'=>'same:confirm-password',
        'roles'=>'required'

        ]);

        $input=$request->all();
        if(!empty($input['password'])){
            $input['password']=Hash::make($input['password']);
        }else{
            $input= Arr::except($input, array('password'));
        }
        $user=User::find($id);
        $user->update($input);
        DB::table('model_has_roles')->where('model_id',$id)->delete();

        $user->assignRole($request->input('roles'));
        return redirect()->route('usuarios.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        User::find($id)->delete();
        return redirect()->route('usuarios.index');
    }
}
