@extends('layouts.app')

@section('content')
<div class="container">
    <h1>Subir Nueva Aplicación</h1>
    <!-- Alertas de Mensajes -->
    <div id="alerta" class="alert d-none" role="alert"></div>

    <form id="upload-form" enctype="multipart/form-data">
        @csrf
        <div class="form-group">
            <label for="nombre">Nombre</label>
            <input type="text" name="nombre" class="form-control" required>
        </div>
        <div class="form-group">
            <label for="descripcion">Descripción</label>
            <textarea name="descripcion" class="form-control"></textarea>
        </div>
        <div class="form-group">
            <label for="archivo_zip">Archivo ZIP</label>
            <input type="file" name="archivo_zip" class="form-control" required>
        </div>
        <button type="submit" class="btn btn-primary" id="btn-submit">Subir</button>
    </form>
</div>

<!-- Scripts -->
@section('scripts')
<script>
    document.addEventListener("DOMContentLoaded", function() {
    const form = document.getElementById('upload-form');
    const alerta = document.getElementById('alerta');
    const btnSubmit = document.getElementById('btn-submit');

    form.addEventListener('submit', function(event) {
        event.preventDefault();

        const formData = new FormData(form);

        btnSubmit.disabled = true;
        btnSubmit.textContent = 'Subiendo...';

        fetch("{{ route('apps.store') }}", {
            method: "POST",
            headers: {
                "X-CSRF-TOKEN": "{{ csrf_token() }}",
                "Accept": "application/json" // Especificar JSON
            },
            body: formData
        })
        .then(response => {
            if (!response.ok) throw new Error('Error en la solicitud.');
            return response.json();
        })
        .then(data => {
            if (data.success) {
                alerta.className = 'alert alert-success';
                alerta.textContent = data.message;
                alerta.classList.remove('d-none');
                form.reset();
            } else {
                throw new Error(data.message);
            }
        })
        .catch(error => {
            alerta.className = 'alert alert-danger';
            alerta.textContent = error.message || 'Error desconocido.';
            alerta.classList.remove('d-none');
        })
        .finally(() => {
            btnSubmit.disabled = false;
            btnSubmit.textContent = 'Subir';
        });
    });
});

</script>
@endsection
@endsection