@extends('layouts.app')

@section('content')
<div class="container">
    <h1>Gestión de Aplicaciones</h1>
    <a href="{{ route('apps.create') }}" class="btn btn-primary mb-3">Subir Nueva Aplicación</a>

    @if(session('success'))
        <div class="alert alert-success">
            {{ session('success') }}
        </div>
    @endif

    @if(session('error'))
        <div class="alert alert-danger">
            {{ session('error') }}
        </div>
    @endif

    <table class="table table-bordered">
        <thead>
            <tr>
                <th>#</th>
                <th>Nombre</th>
                <th>Descripción</th>
                <th>Archivo ZIP</th>
                <th>Estado APK</th>
                <th>Acciones</th>
            </tr>
        </thead>
        <tbody>
            @forelse($apps as $app)
                <tr>
                    <td>{{ $app->id }}</td>
                    <td>{{ $app->nombre }}</td>
                    <td>{{ $app->descripcion }}</td>
                    <td>
                        <a href="{{ asset('storage/' . $app->archivo_zip) }}" target="_blank">
                            Descargar ZIP
                        </a>
                    </td>
                    <td>
                        @if($app->apk_path)
                            <span class="text-success">APK Generado</span>
                        @else
                            <span class="text-danger">Sin Generar</span>
                        @endif
                    </td>
                    <td>
                        <!-- Botón para descomprimir -->
                        @if(!$app->apk_path)
                            <form action="{{ route('apps.descomprimir', $app->id) }}" method="POST" style="display: inline;">
                                @csrf
                                <button type="submit" class="btn btn-warning btn-sm">
                                    Descomprimir
                                </button>
                            </form>
                        @endif

                        <!-- Botón para generar QR -->
                        @if($app->apk_path)
                            <a href="{{ route('apps.generateQr', $app->id) }}" class="btn btn-success btn-sm">
                                Generar QR
                            </a>
                        @endif

                        <!-- Botón para editar -->
                        <a href="{{ route('apps.edit', $app->id) }}" class="btn btn-primary btn-sm">
                            Editar
                        </a>

                        <!-- Botón para eliminar -->
                        <form action="{{ route('apps.destroy', $app->id) }}" method="POST" style="display: inline;">
                            @csrf
                            @method('DELETE')
                            <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar esta aplicación?')">
                                Eliminar
                            </button>
                        </form>
                    </td>
                </tr>
            @empty
                <tr>
                    <td colspan="6" class="text-center">No hay aplicaciones registradas.</td>
                </tr>
            @endforelse
        </tbody>
    </table>

    <!-- Paginación -->
    {{ $apps->links() }}
</div>
@endsection
