<!DOCTYPE html>
<html lang="es">

<head>
    <meta charset="utf-8">
    <title>Sistema Escolar - Rediseñado</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Sistema escolar para gestión educativa">

    <!-- Favicon -->
    <link href="img/favicon.ico" rel="icon">

    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600;700&display=swap" rel="stylesheet">

    <!-- Font Awesome -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css" rel="stylesheet">

    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">

    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f9f9f9;
            color: #333;
        }

        /* Navbar */
        .navbar {
            background: linear-gradient(90deg, #e63946, #7f1d1d);
            color: white;
        }
        .navbar-brand span {
            font-weight: bold;
        }
        .navbar-nav .nav-link {
            color: #fff;
            font-weight: 600;
        }
        .navbar-nav .nav-link:hover {
            color: #f1f1f1;
        }

        /* Hero */
        .hero {
            background: linear-gradient(135deg, #e63946, #7f1d1d);
            color: white;
            text-align: center;
            padding: 80px 0;
        }
        .hero h1 {
            font-weight: 700;
            font-size: 3.5rem;
        }
        .hero p {
            font-size: 1.2rem;
        }
        .hero .btn {
            background-color: #fff;
            color: #e63946;
            font-weight: bold;
            border-radius: 25px;
        }
        .hero .btn:hover {
            background-color: #e63946;
            color: #fff;
        }

        /* Carousel */
        .carousel-item img {
            object-fit: cover;
            height: 500px;
            width: 100%;
        }
        .carousel-caption {
            background: rgba(0, 0, 0, 0.6);
            padding: 10px;
            border-radius: 10px;
        }

        /* Features */
        .features {
            padding: 60px 0;
            background-color: #fff;
        }
        .features h4 {
            color: #e63946;
        }

        /* Footer */
        footer {
            background: #7f1d1d;
            color: #fff;
            padding: 20px 0;
        }
        footer a {
            color: #f1f1f1;
        }
        footer a:hover {
            color: #e63946;
        }
    </style>
</head>

<body>
    <!-- Navbar -->
    <div class="container-fluid p-0 nav-bar">
        <nav class="navbar navbar-expand-lg bg-none navbar-dark py-3">
            <a href="index.html" class="navbar-brand px-lg-4 m-0">
                <h1 class="m-0 display-4 text-uppercase text-white">
                    <img src="img/logo.png" alt="Logo" width="90" height="80" class="d-inline-block align-text-top">
                </h1>
            </a>
            <button type="button" class="navbar-toggler" data-bs-toggle="collapse" data-bs-target="#navbarCollapse">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse justify-content-between" id="navbarCollapse">
                <div class="navbar-nav ml-auto p-4">
                    <a href="/" class="nav-item nav-link{{ request()->is('/') ? ' active' : '' }}">Hogar</a>
                    <a href="{{ route('pages.show', 'about') }}" class="nav-item nav-link{{ request()->is('about') ? ' active' : '' }}">Acerca de</a>
                    <a href="{{ route('pages.show', 'contact') }}" class="nav-item nav-link{{ request()->is('service') ? ' active' : '' }}">Contactos</a>
                    @if (Route::has('login'))
                    @auth
                        <a href="{{ url('/home') }}" class="nav-item nav-link">Panel de administracion</a>
                    @else
                        <a href="{{ url('/login') }}" class="nav-item nav-link">Iniciar sesion</a>
                    @endauth
                    @endif
                </div>
            </div>
        </nav>
    </div>

    <!-- Hero Section -->
    <section class="hero">
        <div class="container">
            <h1>Unidad Educativa Bautista Canadiense</h1>
            <p>Todo lo que necesitas saber en la palma de tu mano</p>
            <a href="{{ route('pages.show', 'contact') }}" {{ request()->is('service') ? ' active' : '' }}" class="btn btn-lg">Conoce Más</a>
        </div>
    </section>

    <!-- Carousel Section -->
    <div id="carouselExampleCaptions" class="carousel slide" data-bs-ride="carousel">
        <div class="carousel-inner">
            <div class="carousel-item active">
                <img src="img/back1.jpg" class="d-block w-100" alt="Slide 1">
                <div class="carousel-caption">
                    <h5>Educación de Calidad</h5>
                    <p>Formamos el futuro con excelencia académica.</p>
                </div>
            </div>
            <div class="carousel-item">
                <img src="img/carrusel2.jpg" class="d-block w-100" alt="Slide 2">
                <div class="carousel-caption">
                    <h5>Innovación Tecnológica</h5>
                    <p>Integración de tecnología para un mejor aprendizaje.</p>
                </div>
            </div>
        </div>
        <button class="carousel-control-prev" type="button" data-bs-target="#carouselExampleCaptions" data-bs-slide="prev">
            <span class="carousel-control-prev-icon" aria-hidden="true"></span>
        </button>
        <button class="carousel-control-next" type="button" data-bs-target="#carouselExampleCaptions" data-bs-slide="next">
            <span class="carousel-control-next-icon" aria-hidden="true"></span>
        </button>
    </div>

    <!-- Features Section -->
    <section class="features text-center">
        <div class="container">
            <div class="row">
                <div class="col-md-4">
                    <i class="fas fa-map-marker-alt fa-3x text-danger mb-3"></i>
                    <h4>Ubicación</h4>
                    <p>Calle Cañada Strongest N° 5624, La Paz, Bolivia</p>
                </div>
                <div class="col-md-4">
                    <i class="fas fa-phone-alt fa-3x text-danger mb-3"></i>
                    <h4>Teléfono</h4>
                    <p>2486262 / 2245640</p>
                </div>
                <div class="col-md-4">
                    <i class="fas fa-envelope fa-3x text-danger mb-3"></i>
                    <h4>Email</h4>
                    <p>escolar@gmail.com</p>
                </div>
            </div>
        </div>
    </section>

    <!-- Footer -->
    <footer class="text-center">
        <div class="container">
            <p>&copy; 2024 Sistema Escolar. Todos los derechos reservados.</p>
            <a href="https://facebook.com" class="text-white"><i class="fab fa-facebook-f fa-2x"></i></a>
        </div>
    </footer>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>
